@@ -341,7 +341,7 @@ from ae.core import DEBUG_LEVELS
 from ae.console import ConsoleApp                                                       # type: ignore
 
 
-__version__ = '0.1.48'
+__version__ = '0.1.49'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -471,7 +471,7 @@ def register_package_images():              # pragma: no cover
 
     package_path = os.path.abspath(os.path.dirname(stack_var('__file__')))
     search_path = os.path.join(package_path, 'img/**')
-    FOUND_IMAGES.add_path(search_path)
+    FOUND_IMAGES.add_paths(search_path)
 
 
 def register_package_sounds():              # pragma: no cover
@@ -480,7 +480,7 @@ def register_package_sounds():              # pragma: no cover
 
     package_path = os.path.abspath(os.path.dirname(stack_var('__file__')))
     search_path = os.path.join(package_path, 'snd/**')
-    FOUND_SOUNDS.add_path(search_path)
+    FOUND_SOUNDS.add_paths(search_path)
 
 
 def replace_flow_action(flow_id: str, new_action: str):
@@ -997,15 +997,15 @@ class MainAppBase(ConsoleApp, ABC):
     def load_images(self):
         """ load images from app folder img. """
         file_reg = FilesRegister()
-        file_reg.add_path('img/**')
-        file_reg.add_files_register(FOUND_IMAGES)
+        file_reg.add_paths('img/**')
+        file_reg.add_register(FOUND_IMAGES)
         self.image_files = file_reg
 
     def load_sounds(self):
         """ load audio sounds from app folder snd. """
         file_reg = FilesRegister()
-        file_reg.add_path('snd/**')
-        file_reg.add_files_register(FOUND_SOUNDS)
+        file_reg.add_paths('snd/**')
+        file_reg.add_register(FOUND_SOUNDS)
         self.sound_files = file_reg
 
     def load_translations(self, lang_code: str):
